# coding: utf-8
# Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20201101

from .discovered_cloud_db_system_component import DiscoveredCloudDbSystemComponent
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DiscoveredCloudDbInstance(DiscoveredCloudDbSystemComponent):
    """
    The details of an Oracle DB instance discovered in a cloud DB system discovery run.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DiscoveredCloudDbInstance object with values from keyword arguments. The default value of the :py:attr:`~oci.database_management.models.DiscoveredCloudDbInstance.component_type` attribute
        of this class is ``DATABASE_INSTANCE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param component_id:
            The value to assign to the component_id property of this DiscoveredCloudDbInstance.
        :type component_id: str

        :param display_name:
            The value to assign to the display_name property of this DiscoveredCloudDbInstance.
        :type display_name: str

        :param component_name:
            The value to assign to the component_name property of this DiscoveredCloudDbInstance.
        :type component_name: str

        :param component_type:
            The value to assign to the component_type property of this DiscoveredCloudDbInstance.
            Allowed values for this property are: "ASM", "ASM_INSTANCE", "CLUSTER", "CLUSTER_INSTANCE", "DATABASE", "DATABASE_INSTANCE", "DATABASE_HOME", "DATABASE_NODE", "DBSYSTEM", "LISTENER", "PLUGGABLE_DATABASE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type component_type: str

        :param resource_id:
            The value to assign to the resource_id property of this DiscoveredCloudDbInstance.
        :type resource_id: str

        :param dbaas_id:
            The value to assign to the dbaas_id property of this DiscoveredCloudDbInstance.
        :type dbaas_id: str

        :param is_selected_for_monitoring:
            The value to assign to the is_selected_for_monitoring property of this DiscoveredCloudDbInstance.
        :type is_selected_for_monitoring: bool

        :param status:
            The value to assign to the status property of this DiscoveredCloudDbInstance.
            Allowed values for this property are: "NEW", "EXISTING", "EXISTING_BASIC", "EXISTING_PE", "EXISTING_BASIC_PE", "MARKED_FOR_UPGRADE", "MARKED_FOR_MIGRATION", "MARKED_FOR_UPGRADE_MIGRATION", "MARKED_FOR_DELETION", "UNKNOWN", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param associated_components:
            The value to assign to the associated_components property of this DiscoveredCloudDbInstance.
        :type associated_components: list[oci.database_management.models.AssociatedCloudComponent]

        :param instance_name:
            The value to assign to the instance_name property of this DiscoveredCloudDbInstance.
        :type instance_name: str

        :param host_name:
            The value to assign to the host_name property of this DiscoveredCloudDbInstance.
        :type host_name: str

        :param node_name:
            The value to assign to the node_name property of this DiscoveredCloudDbInstance.
        :type node_name: str

        :param oracle_home:
            The value to assign to the oracle_home property of this DiscoveredCloudDbInstance.
        :type oracle_home: str

        :param adr_home_directory:
            The value to assign to the adr_home_directory property of this DiscoveredCloudDbInstance.
        :type adr_home_directory: str

        """
        self.swagger_types = {
            'component_id': 'str',
            'display_name': 'str',
            'component_name': 'str',
            'component_type': 'str',
            'resource_id': 'str',
            'dbaas_id': 'str',
            'is_selected_for_monitoring': 'bool',
            'status': 'str',
            'associated_components': 'list[AssociatedCloudComponent]',
            'instance_name': 'str',
            'host_name': 'str',
            'node_name': 'str',
            'oracle_home': 'str',
            'adr_home_directory': 'str'
        }
        self.attribute_map = {
            'component_id': 'componentId',
            'display_name': 'displayName',
            'component_name': 'componentName',
            'component_type': 'componentType',
            'resource_id': 'resourceId',
            'dbaas_id': 'dbaasId',
            'is_selected_for_monitoring': 'isSelectedForMonitoring',
            'status': 'status',
            'associated_components': 'associatedComponents',
            'instance_name': 'instanceName',
            'host_name': 'hostName',
            'node_name': 'nodeName',
            'oracle_home': 'oracleHome',
            'adr_home_directory': 'adrHomeDirectory'
        }
        self._component_id = None
        self._display_name = None
        self._component_name = None
        self._component_type = None
        self._resource_id = None
        self._dbaas_id = None
        self._is_selected_for_monitoring = None
        self._status = None
        self._associated_components = None
        self._instance_name = None
        self._host_name = None
        self._node_name = None
        self._oracle_home = None
        self._adr_home_directory = None
        self._component_type = 'DATABASE_INSTANCE'

    @property
    def instance_name(self):
        """
        **[Required]** Gets the instance_name of this DiscoveredCloudDbInstance.
        The name of the DB instance.


        :return: The instance_name of this DiscoveredCloudDbInstance.
        :rtype: str
        """
        return self._instance_name

    @instance_name.setter
    def instance_name(self, instance_name):
        """
        Sets the instance_name of this DiscoveredCloudDbInstance.
        The name of the DB instance.


        :param instance_name: The instance_name of this DiscoveredCloudDbInstance.
        :type: str
        """
        self._instance_name = instance_name

    @property
    def host_name(self):
        """
        Gets the host_name of this DiscoveredCloudDbInstance.
        The name of the host on which the DB instance is running.


        :return: The host_name of this DiscoveredCloudDbInstance.
        :rtype: str
        """
        return self._host_name

    @host_name.setter
    def host_name(self, host_name):
        """
        Sets the host_name of this DiscoveredCloudDbInstance.
        The name of the host on which the DB instance is running.


        :param host_name: The host_name of this DiscoveredCloudDbInstance.
        :type: str
        """
        self._host_name = host_name

    @property
    def node_name(self):
        """
        Gets the node_name of this DiscoveredCloudDbInstance.
        The name of the DB instance node.


        :return: The node_name of this DiscoveredCloudDbInstance.
        :rtype: str
        """
        return self._node_name

    @node_name.setter
    def node_name(self, node_name):
        """
        Sets the node_name of this DiscoveredCloudDbInstance.
        The name of the DB instance node.


        :param node_name: The node_name of this DiscoveredCloudDbInstance.
        :type: str
        """
        self._node_name = node_name

    @property
    def oracle_home(self):
        """
        Gets the oracle_home of this DiscoveredCloudDbInstance.
        The Oracle home location of the DB instance.


        :return: The oracle_home of this DiscoveredCloudDbInstance.
        :rtype: str
        """
        return self._oracle_home

    @oracle_home.setter
    def oracle_home(self, oracle_home):
        """
        Sets the oracle_home of this DiscoveredCloudDbInstance.
        The Oracle home location of the DB instance.


        :param oracle_home: The oracle_home of this DiscoveredCloudDbInstance.
        :type: str
        """
        self._oracle_home = oracle_home

    @property
    def adr_home_directory(self):
        """
        Gets the adr_home_directory of this DiscoveredCloudDbInstance.
        The Automatic Diagnostic Repository (ADR) home directory for the DB instance.


        :return: The adr_home_directory of this DiscoveredCloudDbInstance.
        :rtype: str
        """
        return self._adr_home_directory

    @adr_home_directory.setter
    def adr_home_directory(self, adr_home_directory):
        """
        Sets the adr_home_directory of this DiscoveredCloudDbInstance.
        The Automatic Diagnostic Repository (ADR) home directory for the DB instance.


        :param adr_home_directory: The adr_home_directory of this DiscoveredCloudDbInstance.
        :type: str
        """
        self._adr_home_directory = adr_home_directory

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
